'\" te
.\" Copyright (c) 2001, the Institute of Electrical and Electronics Engineers, Inc. and The Open Group. All Rights Reserved.
.\" Copyright (c) 1992, X/Open Company Limited.  All Rights Reserved.
.\" Portions Copyright (c) 2006, Sun Microsystems, Inc. All Rights Reserved.
.\" Sun Microsystems, Inc. gratefully acknowledges The Open Group for permission to reproduce portions of its copyrighted documentation. Original documentation from The Open Group can be obtained online at 
.\" http://www.opengroup.org/bookstore/.
.\" The Institute of Electrical and Electronics Engineers and The Open Group, have given us permission to reprint portions of their documentation. In the following statement, the phrase "this text" refers to portions of the system documentation. Portions of this text are reprinted and reproduced in electronic form in the Sun OS Reference Manual, from IEEE Std 1003.1, 2004 Edition, Standard for Information Technology -- Portable Operating System Interface (POSIX), The Open Group Base Specifications Issue 6, Copyright (C) 2001-2004 by the Institute of Electrical and Electronics Engineers, Inc and The Open Group. In the event of any discrepancy between these versions and the original IEEE and The Open Group Standard, the original IEEE and The Open Group Standard is the referee document. The original Standard can be obtained online at http://www.opengroup.org/unix/online.html.
.\"  This notice shall appear on any product containing this material.
.\" The contents of this file are subject to the terms of the Common Development and Distribution License (the "License").  You may not use this file except in compliance with the License.
.\" You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE or http://www.opensolaris.org/os/licensing.  See the License for the specific language governing permissions and limitations under the License.
.\" When distributing Covered Code, include this CDDL HEADER in each file and include the License file at usr/src/OPENSOLARIS.LICENSE.  If applicable, add the following below this CDDL HEADER, with the fields enclosed by brackets "[]" replaced with your own identifying information: Portions Copyright [yyyy] [name of copyright owner]
.TH hypot 3M "1 Sep 2002" "SunOS 5.11" "Mathematical Library Functions"
.SH NAME
hypot, hypotf, hypotl \- Euclidean distance function
.SH SYNOPSIS
.LP
.nf
c99 [ \fIflag\fR... ] \fIfile\fR... \fB-lm\fR [ \fIlibrary\fR... ]
#include <math.h>

\fBdouble\fR \fBhypot\fR(\fBdouble\fR \fIx\fR, \fBdouble\fR \fIy\fR);
.fi

.LP
.nf
\fBfloat\fR \fBhypotf\fR(\fBfloat\fR \fIx\fR, \fBfloat\fR \fIy\fR);
.fi

.LP
.nf
\fBlong double\fR \fBhypotl\fR(\fBlong double\fR \fIx\fR, \fBlong double\fR \fIy\fR);
.fi

.SH DESCRIPTION
.sp
.LP
These functions compute the length of the square root of \fIx\fR^2 + \fIy\fR^2
without undue overflow or underflow.
.SH RETURN VALUES
.sp
.LP
Upon successful completion, these functions return the length of the hypotenuse
of a right angled triangle with sides of length \fIx\fR^2 and \fIy\fR^2.
.sp
.LP
If the correct value would cause overflow, a range error occurs and
\fBhypot()\fR, \fBhypotf()\fR, and \fBhypotl()\fR return the value of the macro
\fBHUGE_VAL\fR, \fBHUGE_VALF\fR, and \fBHUGE_VALL\fR, respectively.
.sp
.LP
If \fIx\fR or \fIy\fR is \(+-Inf, +Inf is returned even if one of \fIx\fR or
\fIy\fR is NaN.
.sp
.LP
If \fIx\fR or \fIy\fR is NaN and the other is not \(+-Inf, a NaN is returned.
.SH ERRORS
.sp
.LP
These functions will fail if:
.sp
.ne 2
.mk
.na
\fBRange Error\fR
.ad
.RS 15n
.rt  
The result overflows.
.sp
If the integer expression (\fBmath_errhandling\fR & \fBMATH_ERREXCEPT\fR) is
non-zero, the overflow floating-point exception is raised.
.RE

.SH USAGE
.sp
.LP
\fBhypot\fR(\fIx\fR,\fIy\fR), \fBhypot\fR(\fIy\fR,\fIx\fR), and
\fBhypot\fR(\fIx\fR, \(mi\fIy\fR) are equivalent.
.sp
.LP
\fBhypot\fR(\fIx\fR, \(+-0) is equivalent to \fBfabs\fR(\fIx\fR).
.sp
.LP
These functions takes precautions against underflow and overflow during
intermediate steps of the computation.
.sp
.LP
An application wanting to check for exceptions should call
\fBfeclearexcept\fR(\fBFE_ALL_EXCEPT\fR) before calling these functions. On
return, if \fBfetestexcept\fR(\fBFE_INVALID\fR | \fBFE_DIVBYZERO\fR |
\fBFE_OVERFLOW\fR | \fBFE_UNDERFLOW\fR) is non-zero, an exception has been
raised. An application should either examine the return value or check the
floating point exception flags to detect exceptions.
.SH ATTRIBUTES
.sp
.LP
See \fBattributes\fR(5) for descriptions of the following attributes:
.sp

.sp
.TS
tab() box;
cw(2.75i) |cw(2.75i) 
lw(2.75i) |lw(2.75i) 
.
ATTRIBUTE TYPEATTRIBUTE VALUE
_
Interface StabilityStandard
_
MT-LevelMT-Safe
.TE

.SH SEE ALSO
.sp
.LP
\fBfabs\fR(3M), \fBfeclearexcept\fR(3M), \fBfetestexcept\fR(3M),
\fBisnan\fR(3M), \fBmath.h\fR(3HEAD), \fBsqrt\fR(3M), \fBattributes\fR(5),
\fBstandards\fR(5)
